//==============================
// Player.H
// 
// Represents a player, its scoring, ...
// 
// ZNibbles
// Vincent Mallet 1997, 1998
//==============================

// $Id: Player.H,v 1.2 1998/11/17 08:35:43 vmallet Exp $

/* ZNibbles - a small multiplayer game
 * Copyright (C) 1997, 1998 Vincent Mallet - vmallet@enst.fr
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef __H_PLAYER__
#define __H_PLAYER__

#include <time.h>
#include <stdlib.h>
#include <unistd.h>

#include "Base.H"

class Trame;


class Player : public Base {
public:
  char   * name;          // player name

  int    number;          // player number
  
  int    socket_number;   // socket number 
  int    score;           // score of player
  int    frag;            // number of times player died
  int    best_length;     // maximum length player reached with a worm
 
  int    worm_id;         // worm of player, 0 if player dead

  int    dead_cycle;      // number of cycles before creating a new worm

  long   playtime;        // time player has been playing for (useless? yes!)
  time_t starttime;       // time player started to play

  int    is_alive;        // used for player lifecheck

  int    two_key;         // boolean: two-key mode
  
  // Constructor ('inline' is here just for emacs' fontifier)
  inline Player(World & wr, int sock = 0) 
    : Base(wr), name(NULL), socket_number(sock), score(0), frag(0), 
      best_length(0),
      worm_id(0), dead_cycle(0), playtime(0), starttime(time(NULL)),
      two_key(0)
  { }

  // Destructor
  inline ~Player() 
  { 
    if (name) free(name); 
    if (socket_number)
      close(socket_number);
  }

  void display();

  void set_name(char *s);
  void set_twokey(int two_key) { this->two_key = two_key; }

  void add_description(Trame& t);   // add player description to trame t
  void read_description(Trame& t);  // update player data from trame t

  void die();

  void quit_game();

  void server_cycle();

}; // class Player



#endif // __H_PLAYER__

